@@ -12,14 +12,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from neutron.common import log as call_log
 from oslo_config import cfg
-from oslo_log import helpers as log_helpers
 
-from neutron_lbaas._i18n import _
 from neutron_lbaas.drivers import driver_base
 
 
-VERSION = "P1.0.0"
+VERSION = "K1.0.0"
 
 driver_opts = [
     cfg.StrOpt('vdirect_address',
@@ -31,25 +30,7 @@ driver_opts = [
                help=_('vDirect user name.')),
     cfg.StrOpt('vdirect_password',
                default='radware',
-               secret=True,
                help=_('vDirect user password.')),
-    cfg.IntOpt('port',
-               default=2189,
-               help=_('vDirect port. Default:2189')),
-    cfg.BoolOpt('ssl',
-               default=True,
-               help=_('Use SSL. Default: True')),
-    cfg.BoolOpt('ssl_verify_context',
-                default=True,
-                help=_('Enables or disables the SSL context verification '
-                       'for legacy python that verifies HTTPS '
-                       'certificates by default. Default: True.')),
-    cfg.IntOpt('timeout',
-               default=5000,
-               help=_('vDirect connection timeout. Default:5000')),
-    cfg.StrOpt('base_uri',
-               default='',
-               help=_('Base vDirect URI. Default:\'\'')),
     cfg.StrOpt('service_adc_type',
                default="VA",
                help=_('Service ADC type. Default: VA.')),
@@ -60,11 +41,6 @@ driver_opts = [
                 default=False,
                 help=_('Enables or disables the Service HA pair. '
                        'Default: False.')),
-    cfg.BoolOpt('configure_allowed_address_pairs',
-                default=False,
-                help=_('Enables or disables allowed address pairs '
-                       'configuration for VIP addresses. '
-                       'Default: False.')),
     cfg.IntOpt('service_throughput',
                default=1000,
                help=_('Service throughput. Default: 1000.')),
@@ -139,8 +115,6 @@ class RadwareLBaaSBaseV2Driver(driver_base.LoadBalancerBaseDriver):
 
         self.load_balancer = LoadBalancerManager(self)
         self.listener = ListenerManager(self)
-        self.l7policy = L7PolicyManager(self)
-        self.l7rule = L7RuleManager(self)
         self.pool = PoolManager(self)
         self.member = MemberManager(self)
         self.health_monitor = HealthMonitorManager(self)
@@ -148,11 +122,11 @@ class RadwareLBaaSBaseV2Driver(driver_base.LoadBalancerBaseDriver):
 
 class LoadBalancerManager(driver_base.BaseLoadBalancerManager):
 
-    @log_helpers.log_method_call
+    @call_log.log
     def create(self, context, lb):
         self.successful_completion(context, lb)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def update(self, context, old_lb, lb):
         if self.driver.workflow_exists(old_lb):
             self.driver.execute_workflow(
@@ -160,15 +134,12 @@ class LoadBalancerManager(driver_base.BaseLoadBalancerManager):
         else:
             self.successful_completion(context, lb)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def delete(self, context, lb):
-        if self.driver.workflow_exists(lb):
-            self.driver.remove_workflow(
-                context, self, lb)
-        else:
-            self.successful_completion(context, lb, delete=True)
+        self.driver.remove_workflow(
+            context, self, lb)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def refresh(self, context, lb):
         if lb.listeners and any(listener.default_pool and
             listener.default_pool.members for listener in lb.listeners):
@@ -177,7 +148,7 @@ class LoadBalancerManager(driver_base.BaseLoadBalancerManager):
         else:
             self.successful_completion(context, lb)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def stats(self, context, lb):
         if self.driver.workflow_exists(lb):
             return self.driver.get_stats(context, lb)
@@ -187,15 +158,11 @@ class LoadBalancerManager(driver_base.BaseLoadBalancerManager):
 
 class ListenerManager(driver_base.BaseListenerManager):
 
-    @log_helpers.log_method_call
+    @call_log.log
     def create(self, context, listener):
-        if self.driver.workflow_exists(listener.root_loadbalancer):
-            self.driver.execute_workflow(
-                context, self, listener)
-        else:
-            self.successful_completion(context, listener)
+        self.successful_completion(context, listener)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def update(self, context, old_listener, listener):
         if self.driver.workflow_exists(old_listener.root_loadbalancer):
             self.driver.execute_workflow(
@@ -203,80 +170,23 @@ class ListenerManager(driver_base.BaseListenerManager):
         else:
             self.successful_completion(context, listener)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def delete(self, context, listener):
         if self.driver.workflow_exists(listener.root_loadbalancer):
             self.driver.execute_workflow(
                 context, self, listener, delete=True)
         else:
-            self.successful_completion(context, listener, delete=True)
-
-
-class L7PolicyManager(driver_base.BaseL7PolicyManager):
-
-    @log_helpers.log_method_call
-    def create(self, context, policy):
-        if self.driver.workflow_exists(policy.root_loadbalancer):
-            self.driver.execute_workflow(
-                context, self, policy)
-        else:
-            self.successful_completion(context, policy)
-
-    @log_helpers.log_method_call
-    def update(self, context, old_policy, policy):
-        if self.driver.workflow_exists(old_policy.root_loadbalancer):
-            self.driver.execute_workflow(
-                context, self, policy, old_data_model=old_policy)
-        else:
-            self.successful_completion(context, policy)
-
-    @log_helpers.log_method_call
-    def delete(self, context, policy):
-        if self.driver.workflow_exists(policy.root_loadbalancer):
-            self.driver.execute_workflow(
-                context, self, policy, delete=True)
-        else:
-            self.successful_completion(context, policy, delete=True)
-
-
-class L7RuleManager(driver_base.BaseL7RuleManager):
-
-    @log_helpers.log_method_call
-    def create(self, context, rule):
-        if self.driver.workflow_exists(rule.root_loadbalancer):
-            self.driver.execute_workflow(
-                context, self, rule)
-        else:
-            self.successful_completion(context, rule)
-
-    @log_helpers.log_method_call
-    def update(self, context, old_rule, rule):
-        if self.driver.workflow_exists(old_rule.root_loadbalancer):
-            self.driver.execute_workflow(
-                context, self, rule, old_data_model=old_rule)
-        else:
-            self.successful_completion(context, rule)
-
-    @log_helpers.log_method_call
-    def delete(self, context, rule):
-        if self.driver.workflow_exists(rule.root_loadbalancer):
-            self.driver.execute_workflow(
-                context, self, rule, delete=True)
-        else:
-            self.successful_completion(context, rule, delete=True)
+            self.successful_completion(context, listener,
+                                       delete=True)
 
 
 class PoolManager(driver_base.BasePoolManager):
 
-    @log_helpers.log_method_call
+    @call_log.log
     def create(self, context, pool):
-        if self.driver.workflow_exists(pool.root_loadbalancer):
-            self.driver.execute_workflow(
-                context, self, pool)
-        else:
-            self.successful_completion(context, pool)
+        self.successful_completion(context, pool)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def update(self, context, old_pool, pool):
         if self.driver.workflow_exists(old_pool.root_loadbalancer):
             self.driver.execute_workflow(
@@ -284,7 +194,7 @@ class PoolManager(driver_base.BasePoolManager):
         else:
             self.successful_completion(context, pool)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def delete(self, context, pool):
         if self.driver.workflow_exists(pool.root_loadbalancer):
             self.driver.execute_workflow(
@@ -296,17 +206,17 @@ class PoolManager(driver_base.BasePoolManager):
 
 class MemberManager(driver_base.BaseMemberManager):
 
-    @log_helpers.log_method_call
+    @call_log.log
     def create(self, context, member):
         self.driver.execute_workflow(
             context, self, member)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def update(self, context, old_member, member):
         self.driver.execute_workflow(
             context, self, member, old_data_model=old_member)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def delete(self, context, member):
         self.driver.execute_workflow(
             context, self, member,
@@ -315,7 +225,7 @@ class MemberManager(driver_base.BaseMemberManager):
 
 class HealthMonitorManager(driver_base.BaseHealthMonitorManager):
 
-    @log_helpers.log_method_call
+    @call_log.log
     def create(self, context, hm):
         if self.driver.workflow_exists(hm.root_loadbalancer):
             self.driver.execute_workflow(
@@ -323,7 +233,7 @@ class HealthMonitorManager(driver_base.BaseHealthMonitorManager):
         else:
             self.successful_completion(context, hm)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def update(self, context, old_hm, hm):
         if self.driver.workflow_exists(old_hm.root_loadbalancer):
             self.driver.execute_workflow(
@@ -331,7 +241,7 @@ class HealthMonitorManager(driver_base.BaseHealthMonitorManager):
         else:
             self.successful_completion(context, hm)
 
-    @log_helpers.log_method_call
+    @call_log.log
     def delete(self, context, hm):
         if self.driver.workflow_exists(hm.root_loadbalancer):
             self.driver.execute_workflow(
